@@ -59,7 +59,7 @@ void help_about_callback ()
 	  "Main program:  Jonathan Blandford (jrb@mit.edu)",
 	  "                      Felix Bellaby (felix@pooh.u-net.com)",
 	  "Card Games:    Jonathan Blandford (jrb@mit.edu)",
-	  "                      Ryu Changwoo (cwryu@eve.kaist.ac.kr)",
+	  "                      Changwoo Ryu (cwryu@adam.kaist.ac.kr)",
 	  "                      Rosanna Yuen (rwsy@mit.edu)",
           NULL
           };
@@ -82,7 +82,6 @@ GnomeUIInfo rules_sub_menu[] = {
 };
 
 GnomeUIInfo file_menu[] = {
-  GNOMEUIINFO_MENU_EXIT_ITEM(quit_app, NULL),
   GNOMEUIINFO_END
 };
 
@@ -143,15 +142,16 @@ GnomeUIInfo game_menu[] = {
   /*  GNOMEUIINFO_ITEM_STOCK(N_("S_tatistics..."), NULL, 
       show_global_stats_dialog, GNOME_STOCK_MENU_BOOK_BLUE), */
 
+  GNOMEUIINFO_SEPARATOR,
+
+  GNOMEUIINFO_MENU_EXIT_ITEM(quit_app, NULL),
+
   GNOMEUIINFO_END
 };
 
 
 GnomeUIInfo top_menu[] = {
 
-  GNOMEUIINFO_MENU_FILE_TREE(file_menu),
-
-
   GNOMEUIINFO_MENU_GAME_TREE(game_menu),
 
   GNOMEUIINFO_MENU_SETTINGS_TREE(settings_menu),
