@@ -374,11 +374,10 @@ GnomeUIInfo gamemenu [] = {
 
 	 GNOMEUIINFO_MENU_HINT_ITEM(hint_callback, NULL),
 
-	 GNOMEUIINFO_END
-};
+	 GNOMEUIINFO_SEPARATOR,
 
-GnomeUIInfo filemenu [] = {
          GNOMEUIINFO_MENU_EXIT_ITEM(quit_game_callback, NULL),
+
 	 GNOMEUIINFO_END
 };
 
@@ -406,7 +405,6 @@ GnomeUIInfo helpmenu[] = {
 };
 
 GnomeUIInfo mainmenu [] = {
-        GNOMEUIINFO_MENU_FILE_TREE(filemenu),
 	GNOMEUIINFO_MENU_GAME_TREE(gamemenu),
 	GNOMEUIINFO_MENU_SETTINGS_TREE(settingsmenu),
 	GNOMEUIINFO_MENU_HELP_TREE(helpmenu),
@@ -932,16 +930,16 @@ gint hint_timeout (gpointer data)
   timeout_counter ++;
   
   if (timeout_counter > HINT_BLINK_NUM)
-    return 0;
+	  return 0;
   
   tiles[hint_tiles[0]].selected ^= HINT_FLAG;
   tiles[hint_tiles[1]].selected ^= HINT_FLAG;
   change_tile_image(&tiles[hint_tiles[0]]);
   change_tile_image(&tiles[hint_tiles[1]]);
-
+  
   return 1;
 }
-
+  
 void hint_callback (GtkWidget *widget, gpointer data)
 {
   int i, j, free=0, type ;
@@ -953,13 +951,13 @@ void hint_callback (GtkWidget *widget, gpointer data)
   
   if (timeout_counter<=HINT_BLINK_NUM) 
     return;
-
+  
   /* Snarfed from check free
    * Tile Free is now _so_ much quicker, it is more elegant to do a
    * British Library search, and safer. */
-
+  
   if (selected_tile < MAX_TILES) {
-	  tiles[selected_tile].selected = 0;
+    tiles[selected_tile].selected = 0;
   }
   selected_tile = MAX_TILES + 1;
   
@@ -980,12 +978,12 @@ void hint_callback (GtkWidget *widget, gpointer data)
 		hint_tiles[1] = j;
 	      }
 	  }
-      }
+	}
   /* This is a good way to test check_free
-    for (i=0;i<MAX_TILES;i++)
-    if (tiles[i].selected == 17)
-    tiles[i].visible = 0 ;*/
-
+     for (i=0;i<MAX_TILES;i++)
+     if (tiles[i].selected == 17)
+     tiles[i].visible = 0 ;*/
+  
   timeout_counter = 0;
   timer = gtk_timeout_add (250, (GtkFunction) hint_timeout, NULL);
 }
@@ -1089,7 +1087,7 @@ void undo_tile_callback (GtkWidget *widget, gpointer data)
     if (selected_tile<MAX_TILES) 
       {
 	tiles[selected_tile].selected = 0 ;
-	change_tile_image (&tiles[i]);
+	change_tile_image (&tiles[selected_tile]);
 	selected_tile = MAX_TILES + 1; 
       }
 
@@ -1283,7 +1281,11 @@ void load_tiles (char *fname)
 	g_free (tmp);
 
 	if (!g_file_exists (fn)) {
-		printf ("Could not find file \'%s\'\n", fn);
+		char *s = g_strdup_printf (_("Could not find file %s"), fn);
+		GtkWidget *box;
+		
+		box = gnome_message_box_new (s, GNOME_MESSAGE_BOX_ERROR, GNOME_STOCK_BUTTON_OK, NULL);
+		gnome_dialog_run (GNOME_DIALOG (box));
 		exit (1);
 	}
 
@@ -1425,6 +1427,7 @@ int main (int argc, char *argv [])
 	gnome_app_set_contents (GNOME_APP (window), mbox);
 	create_mahjongg_board ();
 
+	gtk_widget_realize (window);
 	gtk_widget_show (window);
 	gtk_main ();
 	
